@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -22,11 +22,21 @@
 
 #include <memory>
 
-
+#include <fst/log.h>
+#include <fst/arc.h>
 #include <fst/cache.h>
 #include <fst/complement.h>
+#include <fst/compose-filter.h>
 #include <fst/compose.h>
-
+#include <fst/connect.h>
+#include <fst/float-weight.h>
+#include <fst/fst.h>
+#include <fst/impl-to-fst.h>
+#include <fst/matcher.h>
+#include <fst/mutable-fst.h>
+#include <fst/properties.h>
+#include <fst/state-table.h>
+#include <fst/util.h>
 
 namespace fst {
 
