@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -39,15 +39,25 @@
 #ifndef FST_EDIT_FST_H_
 #define FST_EDIT_FST_H_
 
+#include <cstddef>
 #include <cstdint>
+#include <istream>
+#include <memory>
+#include <ostream>
 #include <string>
 #include <vector>
 
 #include <fst/log.h>
-
 #include <fst/cache.h>
-
+#include <fst/expanded-fst.h>
+#include <fst/fst.h>
+#include <fst/impl-to-fst.h>
+#include <fst/mutable-fst.h>
+#include <fst/properties.h>
+#include <fst/util.h>
+#include <fst/vector-fst.h>
 #include <unordered_map>
+#include <string_view>
 
 namespace fst {
 namespace internal {
@@ -82,7 +92,7 @@ class EditFstData {
         edited_final_weights_(other.edited_final_weights_),
         num_new_states_(other.num_new_states_) {}
 
-  ~EditFstData() {}
+  ~EditFstData() = default;
 
   static EditFstData *Read(std::istream &strm, const FstReadOptions &opts);
 
@@ -313,7 +323,7 @@ template <typename A, typename WrappedFstT, typename MutableFstT>
 EditFstData<A, WrappedFstT, MutableFstT> *
 EditFstData<A, WrappedFstT, MutableFstT>::Read(std::istream &strm,
                                                const FstReadOptions &opts) {
-  auto *data = new EditFstData;
+  auto data = fst::make_unique_for_overwrite<EditFstData>();
   // Next read in MutabelFstT machine that stores edits
   FstReadOptions edits_opts(opts);
   // Contained header was written out, so read it in.
@@ -337,7 +347,7 @@ EditFstData<A, WrappedFstT, MutableFstT>::Read(std::istream &strm,
     LOG(ERROR) << "EditFst::Read: read failed: " << opts.source;
     return nullptr;
   }
-  return data;
+  return data.release();
 }
 
 // This class enables non-destructive edit operations on a wrapped ExpandedFst.
@@ -603,7 +613,7 @@ template <typename Arc, typename WrappedFstT, typename MutableFstT>
 EditFstImpl<Arc, WrappedFstT, MutableFstT> *
 EditFstImpl<Arc, WrappedFstT, MutableFstT>::Read(std::istream &strm,
                                                  const FstReadOptions &opts) {
-  auto *impl = new EditFstImpl();
+  auto impl = std::make_unique<EditFstImpl>();
   FstHeader hdr;
   if (!impl->ReadHeader(strm, opts, kMinFileVersion, &hdr)) return nullptr;
   impl->SetStart(hdr.Start());
@@ -617,7 +627,7 @@ EditFstImpl<Arc, WrappedFstT, MutableFstT>::Read(std::istream &strm,
   impl->data_ = std::shared_ptr<EditFstData<Arc, WrappedFstT, MutableFstT>>(
       EditFstData<Arc, WrappedFstT, MutableFstT>::Read(strm, opts));
   if (!impl->data_) return nullptr;
-  return impl;
+  return impl.release();
 }
 
 }  // namespace internal
@@ -649,7 +659,7 @@ class EditFst : public ImplToMutableFst<
   EditFst(const EditFst &fst, bool safe = false)
       : ImplToMutableFst<Impl>(fst, safe) {}
 
-  ~EditFst() override {}
+  ~EditFst() override = default;
 
   // Gets a copy of this EditFst. See Fst<>::Copy() for further doc.
   EditFst *Copy(bool safe = false) const override {
@@ -674,7 +684,7 @@ class EditFst : public ImplToMutableFst<
 
   // Reads an EditFst from a file, returning nullptr on error. If the source
   // argument is an empty string, it reads from standard input.
-  static EditFst *Read(const std::string &source) {
+  static EditFst *Read(std::string_view source) {
     auto *impl = ImplToExpandedFst<Impl, MutableFst<Arc>>::Read(source);
     return impl ? new EditFst(std::shared_ptr<Impl>(impl)) : nullptr;
   }
