@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,8 +20,12 @@
 #ifndef FST_ENCODE_H_
 #define FST_ENCODE_H_
 
+#include <climits>
+#include <cstddef>
 #include <cstdint>
+#include <ios>
 #include <iostream>
+#include <istream>
 #include <memory>
 #include <ostream>
 #include <string>
@@ -30,11 +34,19 @@
 
 #include <fst/log.h>
 #include <fst/arc-map.h>
+#include <fst/arc.h>
+#include <fst/cache.h>
 #include <fstream>
+#include <fst/float-weight.h>
+#include <fst/fst.h>
+#include <fst/impl-to-fst.h>
+#include <fst/mutable-fst.h>
 #include <fst/properties.h>
 #include <fst/rmfinalepsilon.h>
+#include <fst/symbol-table.h>
 #include <fst/util.h>
 #include <unordered_map>
+#include <string_view>
 
 namespace fst {
 
@@ -53,6 +65,8 @@ inline constexpr uint8_t kEncodeHasOSymbols = 0x08;
 
 // Identifies stream data as an encode table (and its endianity).
 inline constexpr int32_t kEncodeMagicNumber = 2128178506;
+// TODO(b/141172858): deprecated, remove by 2020-01-01.
+inline constexpr int32_t kEncodeDeprecatedMagicNumber = 2129983209;
 
 }  // namespace internal
 
@@ -71,7 +85,9 @@ class EncodeTableHeader {
 
   // Setters.
 
-  void SetArcType(const std::string &arctype) { arctype_ = arctype; }
+  void SetArcType(std::string_view arctype) {
+    arctype_ = std::string(arctype);
+  }
 
   void SetFlags(uint8_t flags) { flags_ = flags; }
 
@@ -79,9 +95,9 @@ class EncodeTableHeader {
 
   // IO.
 
-  bool Read(std::istream &strm, const std::string &source);
+  bool Read(std::istream &strm, std::string_view source);
 
-  bool Write(std::ostream &strm, const std::string &source) const;
+  bool Write(std::ostream &strm, std::string_view source) const;
 
  private:
   std::string arctype_;
@@ -192,9 +208,9 @@ class EncodeTable {
 
   size_t Size() const { return triples_.size(); }
 
-  static EncodeTable *Read(std::istream &strm, const std::string &source);
+  static EncodeTable *Read(std::istream &strm, std::string_view source);
 
-  bool Write(std::ostream &strm, const std::string &source) const;
+  bool Write(std::ostream &strm, std::string_view source) const;
 
   // This is masked to hide internal-only isymbol and osymbol bits.
 
@@ -245,7 +261,7 @@ class EncodeTable {
 
 template <class Arc>
 EncodeTable<Arc> *EncodeTable<Arc>::Read(std::istream &strm,
-                                         const std::string &source) {
+                                         std::string_view source) {
   EncodeTableHeader hdr;
   if (!hdr.Read(strm, source)) return nullptr;
   const auto flags = hdr.Flags();
@@ -270,7 +286,7 @@ EncodeTable<Arc> *EncodeTable<Arc>::Read(std::istream &strm,
 
 template <class Arc>
 bool EncodeTable<Arc>::Write(std::ostream &strm,
-                             const std::string &source) const {
+                             std::string_view source) const {
   EncodeTableHeader hdr;
   hdr.SetArcType(Arc::Type());
   hdr.SetFlags(flags_);  // Real flags, not masked ones.
@@ -361,20 +377,30 @@ class EncodeMapper {
                                : kRmSuperFinalProperties);
     }
     if (type_ == ENCODE) mask |= kIDeterministic;
-    return outprops & mask;
+    outprops &= mask;
+    if (type_ == ENCODE) {
+      if (flags_ & kEncodeLabels) {
+        outprops |= kAcceptor;
+      }
+      if (flags_ & kEncodeWeights) {
+        outprops |= kUnweighted | kUnweightedCycles;
+      }
+    }
+    return outprops;
   }
 
   EncodeType Type() const { return type_; }
 
-  static EncodeMapper *Read(std::istream &strm, const std::string &source,
+  static EncodeMapper *Read(std::istream &strm, std::string_view source,
                             EncodeType type = ENCODE) {
     auto *table = internal::EncodeTable<Arc>::Read(strm, source);
     return table ? new EncodeMapper(table->Flags(), type, table) : nullptr;
   }
 
-  static EncodeMapper *Read(const std::string &source,
+  static EncodeMapper *Read(std::string_view source,
                             EncodeType type = ENCODE) {
-    std::ifstream strm(source, std::ios_base::in | std::ios_base::binary);
+    std::ifstream strm(std::string(source),
+                            std::ios_base::in | std::ios_base::binary);
     if (!strm) {
       LOG(ERROR) << "EncodeMapper: Can't open file: " << source;
       return nullptr;
@@ -382,12 +408,12 @@ class EncodeMapper {
     return Read(strm, source, type);
   }
 
-  bool Write(std::ostream &strm, const std::string &source) const {
+  bool Write(std::ostream &strm, std::string_view source) const {
     return table_->Write(strm, source);
   }
 
-  bool Write(const std::string &source) const {
-    std::ofstream strm(source,
+  bool Write(std::string_view source) const {
+    std::ofstream strm(std::string(source),
                              std::ios_base::out | std::ios_base::binary);
     if (!strm) {
       LOG(ERROR) << "EncodeMapper: Can't open file: " << source;
