@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -23,17 +23,22 @@
 #include <algorithm>
 #include <climits>
 #include <cmath>
+#include <cstddef>
 #include <cstdint>
+#include <cstdlib>
 #include <cstring>
+#include <ios>
+#include <istream>
 #include <limits>
+#include <ostream>
 #include <random>
 #include <sstream>
 #include <string>
 #include <type_traits>
 
+#include <fst/log.h>
 #include <fst/util.h>
 #include <fst/weight.h>
-
 #include <fst/compat.h>
 #include <string_view>
 
@@ -68,7 +73,7 @@ class FloatWeightTpl {
  public:
   using ValueType = T;
 
-  FloatWeightTpl() noexcept {}
+  FloatWeightTpl() noexcept = default;
 
   constexpr FloatWeightTpl(T f) : value_(f) {}  // NOLINT
 
@@ -94,12 +99,11 @@ class FloatWeightTpl {
   void SetValue(const T &f) { value_ = f; }
 
   static constexpr std::string_view GetPrecisionString() {
-    return sizeof(T) == 4
-               ? ""
-               : sizeof(T) == 1
-                     ? "8"
-                     : sizeof(T) == 2 ? "16"
-                                      : sizeof(T) == 8 ? "64" : "unknown";
+    return sizeof(T) == 4   ? ""
+           : sizeof(T) == 1 ? "8"
+           : sizeof(T) == 2 ? "16"
+           : sizeof(T) == 8 ? "64"
+                            : "unknown";
   }
 
  private:
@@ -267,7 +271,8 @@ template <class T>
 constexpr TropicalWeightTpl<T> Plus(const TropicalWeightTpl<T> &w1,
                                     const TropicalWeightTpl<T> &w2) {
   return (!w1.Member() || !w2.Member()) ? TropicalWeightTpl<T>::NoWeight()
-                                        : w1.Value() < w2.Value() ? w1 : w2;
+         : w1.Value() < w2.Value()      ? w1
+                                        : w2;
 }
 
 // See comment at operator==(FloatWeightTpl<float>, FloatWeightTpl<float>)
@@ -395,10 +400,9 @@ template <class T, class V, bool Enable = !std::is_same_v<V, size_t>,
           typename std::enable_if_t<Enable> * = nullptr>
 constexpr TropicalWeightTpl<T> Power(const TropicalWeightTpl<T> &w, V n) {
   using Weight = TropicalWeightTpl<T>;
-  return (!w.Member() || internal::IsNan(n))
-             ? Weight::NoWeight()
-             : (n == 0 || w == Weight::One()) ? Weight::One()
-                                              : Weight(w.Value() * n);
+  return (!w.Member() || internal::IsNan(n)) ? Weight::NoWeight()
+         : (n == 0 || w == Weight::One())    ? Weight::One()
+                                             : Weight(w.Value() * n);
 }
 
 // Specializes the library-wide template to use the above implementation; rules
@@ -602,10 +606,9 @@ template <class T, class V, bool Enable = !std::is_same_v<V, size_t>,
           typename std::enable_if_t<Enable> * = nullptr>
 constexpr LogWeightTpl<T> Power(const LogWeightTpl<T> &w, V n) {
   using Weight = LogWeightTpl<T>;
-  return (!w.Member() || internal::IsNan(n))
-             ? Weight::NoWeight()
-             : (n == 0 || w == Weight::One()) ? Weight::One()
-                                              : Weight(w.Value() * n);
+  return (!w.Member() || internal::IsNan(n)) ? Weight::NoWeight()
+         : (n == 0 || w == Weight::One())    ? Weight::One()
+                                             : Weight(w.Value() * n);
 }
 
 // Specializes the library-wide template to use the above implementation; rules
@@ -805,10 +808,9 @@ template <class T, class V, bool Enable = !std::is_same_v<V, size_t>,
           typename std::enable_if_t<Enable> * = nullptr>
 constexpr RealWeightTpl<T> Power(const RealWeightTpl<T> &w, V n) {
   using Weight = RealWeightTpl<T>;
-  return (!w.Member() || internal::IsNan(n))
-             ? Weight::NoWeight()
-             : (n == 0 || w == Weight::One()) ? Weight::One()
-                                              : Weight(pow(w.Value(), n));
+  return (!w.Member() || internal::IsNan(n)) ? Weight::NoWeight()
+         : (n == 0 || w == Weight::One())    ? Weight::One()
+                                             : Weight(pow(w.Value(), n));
 }
 
 // Specializes the library-wide template to use the above implementation; rules
@@ -912,7 +914,8 @@ template <class T>
 constexpr MinMaxWeightTpl<T> Plus(const MinMaxWeightTpl<T> &w1,
                                   const MinMaxWeightTpl<T> &w2) {
   return (!w1.Member() || !w2.Member()) ? MinMaxWeightTpl<T>::NoWeight()
-                                        : w1.Value() < w2.Value() ? w1 : w2;
+         : w1.Value() < w2.Value()      ? w1
+                                        : w2;
 }
 
 constexpr MinMaxWeightTpl<float> Plus(const MinMaxWeightTpl<float> &w1,
@@ -930,7 +933,8 @@ template <class T>
 constexpr MinMaxWeightTpl<T> Times(const MinMaxWeightTpl<T> &w1,
                                    const MinMaxWeightTpl<T> &w2) {
   return (!w1.Member() || !w2.Member()) ? MinMaxWeightTpl<T>::NoWeight()
-                                        : w1.Value() >= w2.Value() ? w1 : w2;
+         : w1.Value() >= w2.Value()     ? w1
+                                        : w2;
 }
 
 constexpr MinMaxWeightTpl<float> Times(const MinMaxWeightTpl<float> &w1,
