@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,6 +20,8 @@
 #ifndef FST_SHORTEST_PATH_H_
 #define FST_SHORTEST_PATH_H_
 
+#include <algorithm>
+#include <cstddef>
 #include <cstdint>
 #include <functional>
 #include <type_traits>
@@ -27,13 +29,19 @@
 #include <vector>
 
 #include <fst/log.h>
-
+#include <fst/arc.h>
+#include <fst/arcfilter.h>
 #include <fst/cache.h>
+#include <fst/connect.h>
 #include <fst/determinize.h>
+#include <fst/fst.h>
+#include <fst/mutable-fst.h>
+#include <fst/properties.h>
 #include <fst/queue.h>
+#include <fst/reverse.h>
 #include <fst/shortest-distance.h>
-#include <fst/test-properties.h>
-
+#include <fst/vector-fst.h>
+#include <fst/weight.h>
 
 namespace fst {
 
@@ -264,9 +272,9 @@ class ShortestPathCompare {
 
  private:
   Weight PWeight(StateId state) const {
-    return (state == superfinal_)
-               ? Weight::One()
-               : (state < distance_.size()) ? distance_[state] : Weight::Zero();
+    return (state == superfinal_)       ? Weight::One()
+           : (state < distance_.size()) ? distance_[state]
+                                        : Weight::Zero();
   }
 
   const std::vector<std::pair<StateId, Weight>> &pairs_;
@@ -361,10 +369,9 @@ void NShortestPath(const Fst<RevArc> &ifst, MutableFst<Arc> *ofst,
     const auto state = heap.back();
     const auto p = pairs[state];
     heap.pop_back();
-    const auto d =
-        (p.first == kNoStateId)
-            ? Weight::One()
-            : (p.first < distance.size()) ? distance[p.first] : Weight::Zero();
+    const auto d = (p.first == kNoStateId)       ? Weight::One()
+                   : (p.first < distance.size()) ? distance[p.first]
+                                                 : Weight::Zero();
     if (less(limit, Times(d, p.second)) ||
         (state_threshold != kNoStateId &&
          ofst->NumStates() >= state_threshold)) {
