@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,12 +20,17 @@
 #ifndef FST_SYMBOL_TABLE_H_
 #define FST_SYMBOL_TABLE_H_
 
+#include <sys/types.h>
+
+#include <cstddef>
 #include <cstdint>
 #include <functional>
 #include <ios>
 #include <iostream>
+#include <istream>
 #include <iterator>
 #include <memory>
+#include <ostream>
 #include <sstream>
 #include <string>
 #include <type_traits>
@@ -43,6 +48,7 @@
 #include <fst/lock.h>
 
 DECLARE_bool(fst_compat_symbols);
+DECLARE_string(fst_field_separator);
 
 namespace fst {
 
@@ -50,13 +56,6 @@ inline constexpr int64_t kNoSymbol = -1;
 
 class SymbolTable;
 
-struct SymbolTableTextOptions {
-  explicit SymbolTableTextOptions(bool allow_negative_labels = false);
-
-  bool allow_negative_labels;
-  std::string fst_field_separator;
-};
-
 namespace internal {
 
 // Maximum line length in textual symbols file.
@@ -210,12 +209,17 @@ class SymbolTableImpl final : public MutableSymbolTableImpl {
   // potentially reduced size of the dense key interval.
   void RemoveSymbol(int64_t key) override;
 
-  static SymbolTableImpl *ReadText(
+  static SymbolTableImpl * ReadText(
       std::istream &strm, std::string_view name,
-      const SymbolTableTextOptions &opts = SymbolTableTextOptions());
+      // Characters to be used as a separator between fields in a textual
+      // `SymbolTable` file, encoded as a string. Each byte in the string is
+      // considered a valid separator. Multi-byte separators are not permitted.
+      // The default value, "\t ", accepts space and tab.
+      const std::string &sep = FST_FLAGS_fst_field_separator);
 
   // Reads a binary SymbolTable from stream, using source in error messages.
-  static SymbolTableImpl *Read(std::istream &strm, std::string_view source);
+  static SymbolTableImpl * Read(std::istream &strm,
+                                                std::string_view source);
 
   bool Write(std::ostream &strm) const override;
 
@@ -370,25 +374,25 @@ class SymbolTable {
   explicit SymbolTable(std::string_view name = "<unspecified>")
       : impl_(std::make_shared<internal::SymbolTableImpl>(name)) {}
 
-  virtual ~SymbolTable() {}
+  virtual ~SymbolTable() = default;
 
   // Reads a text representation of the symbol table from an istream. Pass a
   // name to give the resulting SymbolTable.
   static SymbolTable *ReadText(
       std::istream &strm, std::string_view name,
-      const SymbolTableTextOptions &opts = SymbolTableTextOptions()) {
+      const std::string &sep = FST_FLAGS_fst_field_separator) {
     auto impl =
-        fst::WrapUnique(internal::SymbolTableImpl::ReadText(strm, name, opts));
+        fst::WrapUnique(internal::SymbolTableImpl::ReadText(strm, name, sep));
     return impl ? new SymbolTable(std::move(impl)) : nullptr;
   }
 
   // Reads a text representation of the symbol table.
-  static SymbolTable *ReadText(
+  static SymbolTable * ReadText(
       const std::string &source,
-      const SymbolTableTextOptions &opts = SymbolTableTextOptions());
+      const std::string &sep = FST_FLAGS_fst_field_separator);
 
   // Reads a binary dump of the symbol table from a stream.
-  static SymbolTable *Read(std::istream &strm, const std::string &source) {
+  static SymbolTable *Read(std::istream &strm, std::string_view source) {
     auto impl = fst::WrapUnique(internal::SymbolTableImpl::Read(strm, source));
     return impl ? new SymbolTable(std::move(impl)) : nullptr;
   }
@@ -481,11 +485,17 @@ class SymbolTable {
   bool Write(const std::string &source) const;
 
   // Dumps a text representation of the symbol table via a stream.
-  bool WriteText(std::ostream &strm, const SymbolTableTextOptions &opts =
-                                         SymbolTableTextOptions()) const;
+  bool WriteText(
+      std::ostream &strm,
+      // Characters to be used as a separator between fields in a textual
+      // `SymbolTable` file, encoded as a string. Each byte in the string is
+      // considered a valid separator. Multi-byte separators are not permitted.
+      // The default value, "\t ", outputs tab.
+      const std::string &sep = FST_FLAGS_fst_field_separator) const;
 
   // Dumps a text representation of the symbol table.
-  bool WriteText(const std::string &source) const;
+  bool WriteText(const std::string &sink,
+                 const std::string &sep = FST_FLAGS_fst_field_separator) const;
 
   const_iterator begin() const { return const_iterator(*this, 0); }
 
@@ -529,7 +539,7 @@ class OPENFST_DEPRECATED(
   explicit SymbolTableIterator(const SymbolTable &table)
       : table_(table), iter_(table.begin()), end_(table.end()) {}
 
-  ~SymbolTableIterator() {}
+  ~SymbolTableIterator() = default;
 
   // Returns whether iterator is done.
   bool Done() const { return (iter_ == end_); }
@@ -562,13 +572,13 @@ template <class Label>
 SymbolTable *RelabelSymbolTable(
     const SymbolTable *table,
     const std::vector<std::pair<Label, Label>> &pairs) {
-  auto *new_table = new SymbolTable(
+  auto new_table = std::make_unique<SymbolTable>(
       table->Name().empty() ? std::string()
                             : (std::string("relabeled_") + table->Name()));
   for (const auto &[old_label, new_label] : pairs) {
     new_table->AddSymbol(table->Find(old_label), new_label);
   }
-  return new_table;
+  return new_table.release();
 }
 
 // Returns true if the two symbol tables have equal checksums. Passing in
