@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -22,17 +22,28 @@
 
 #include <algorithm>
 #include <atomic>
+#include <cstddef>
 #include <cstdint>
+#include <ios>
+#include <iosfwd>
+#include <istream>
 #include <memory>
+#include <new>
+#include <ostream>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include <fst/log.h>
-
+#include <fst/arc.h>
+#include <fst/expanded-fst.h>
+#include <fst/float-weight.h>
 #include <fst/fst-decl.h>  // For optional argument declarations
+#include <fst/fst.h>
 #include <fst/mutable-fst.h>
-#include <fst/test-properties.h>
+#include <fst/properties.h>
+#include <fst/util.h>
+#include <string_view>
 
 namespace fst {
 
@@ -55,11 +66,7 @@ class VectorState {
       ArcAllocator>::template rebind_alloc<VectorState<Arc, M>>;
 
   // Provide STL allocator for arcs.
-  explicit VectorState(const ArcAllocator &alloc)
-      : final_weight_(Weight::Zero()),
-        niepsilons_(0),
-        noepsilons_(0),
-        arcs_(alloc) {}
+  explicit VectorState(const ArcAllocator &alloc) : arcs_(alloc) {}
 
   VectorState(const VectorState<A, M> &state, const ArcAllocator &alloc)
       : final_weight_(state.Final()),
@@ -107,7 +114,7 @@ class VectorState {
   }
 
   template <class... T>
-  void EmplaceArc(T &&... ctor_args) {
+  void EmplaceArc(T &&...ctor_args) {
     arcs_.emplace_back(std::forward<T>(ctor_args)...);
     IncrementNumEpsilons(arcs_.back());
   }
@@ -153,10 +160,10 @@ class VectorState {
     if (arc.olabel == 0) ++noepsilons_;
   }
 
-  Weight final_weight_;                // Final weight.
-  size_t niepsilons_;                  // # of input epsilons
-  size_t noepsilons_;                  // # of output epsilons
-  std::vector<A, ArcAllocator> arcs_;  // Arc container.
+  Weight final_weight_ = Weight::Zero();  // Final weight.
+  size_t niepsilons_ = 0;                 // # of input epsilons
+  size_t noepsilons_ = 0;                 // # of output epsilons
+  std::vector<A, ArcAllocator> arcs_;     // Arc container.
 };
 
 namespace internal {
@@ -171,7 +178,7 @@ class VectorFstBaseImpl : public FstImpl<typename S::Arc> {
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
 
-  VectorFstBaseImpl() : start_(kNoStateId) {}
+  VectorFstBaseImpl() = default;
 
   ~VectorFstBaseImpl() override {
     for (auto *state : states_) State::Destroy(state, &state_alloc_);
@@ -244,7 +251,7 @@ class VectorFstBaseImpl : public FstImpl<typename S::Arc> {
   }
 
   template <class... T>
-  void EmplaceArc(StateId state, T &&... ctor_args) {
+  void EmplaceArc(StateId state, T &&...ctor_args) {
     states_[state]->EmplaceArc(std::forward<T>(ctor_args)...);
   }
 
@@ -325,7 +332,7 @@ class VectorFstBaseImpl : public FstImpl<typename S::Arc> {
   State *CreateState() { return new (&state_alloc_) State(arc_alloc_); }
 
   std::vector<State *> states_;
-  StateId start_;
+  StateId start_ = kNoStateId;
   typename State::StateAllocator state_alloc_;
   typename State::ArcAllocator arc_alloc_;
 };
@@ -400,7 +407,7 @@ class VectorFstImpl : public VectorFstBaseImpl<S> {
   }
 
   template <class... T>
-  void EmplaceArc(StateId state, T &&... ctor_args) {
+  void EmplaceArc(StateId state, T &&...ctor_args) {
     BaseImpl::EmplaceArc(state, std::forward<T>(ctor_args)...);
     UpdatePropertiesAfterAddArc(state);
   }
@@ -450,8 +457,8 @@ VectorFstImpl<S>::VectorFstImpl(const Fst<Arc> &fst) {
   SetInputSymbols(fst.InputSymbols());
   SetOutputSymbols(fst.OutputSymbols());
   BaseImpl::SetStart(fst.Start());
-  if (fst.Properties(kExpanded, false)) {
-    BaseImpl::ReserveStates(CountStates(fst));
+  if (std::optional<StateId> num_states = fst.NumStatesIfKnown()) {
+    BaseImpl::ReserveStates(*num_states);
   }
   for (StateIterator<Fst<Arc>> siter(fst); !siter.Done(); siter.Next()) {
     const auto state = siter.Value();
@@ -557,7 +564,7 @@ class VectorFst : public ImplToMutableFst<internal::VectorFstImpl<S>> {
   }
 
   template <class... T>
-  void EmplaceArc(StateId state, T &&... ctor_args) {
+  void EmplaceArc(StateId state, T &&...ctor_args) {
     MutateCheck();
     GetMutableImpl()->EmplaceArc(state, std::forward<T>(ctor_args)...);
   }
@@ -570,7 +577,7 @@ class VectorFst : public ImplToMutableFst<internal::VectorFstImpl<S>> {
 
   // Read a VectorFst from a file, returning nullptr on error; empty source
   // reads from standard input.
-  static VectorFst *Read(const std::string &source) {
+  static VectorFst *Read(std::string_view source) {
     auto *impl = ImplToExpandedFst<Impl, MutableFst<Arc>>::Read(source);
     return impl ? new VectorFst(std::shared_ptr<Impl>(impl)) : nullptr;
   }
@@ -681,7 +688,7 @@ class StateIterator<VectorFst<Arc, State>> {
   using StateId = typename Arc::StateId;
 
   explicit StateIterator(const VectorFst<Arc, State> &fst)
-      : nstates_(fst.GetImpl()->NumStates()), s_(0) {}
+      : nstates_(fst.GetImpl()->NumStates()) {}
 
   bool Done() const { return s_ >= nstates_; }
 
@@ -693,7 +700,7 @@ class StateIterator<VectorFst<Arc, State>> {
 
  private:
   const StateId nstates_;
-  StateId s_;
+  StateId s_ = 0;
 };
 
 // Specialization for VectorFst; see generic version in fst.h for sample usage
@@ -705,8 +712,7 @@ class ArcIterator<VectorFst<Arc, State>> {
 
   ArcIterator(const VectorFst<Arc, State> &fst, StateId s)
       : arcs_(fst.GetImpl()->GetState(s)->Arcs()),
-        narcs_(fst.GetImpl()->GetState(s)->NumArcs()),
-        i_(0) {}
+        narcs_(fst.GetImpl()->GetState(s)->NumArcs()) {}
 
   bool Done() const { return i_ >= narcs_; }
 
@@ -727,7 +733,7 @@ class ArcIterator<VectorFst<Arc, State>> {
  private:
   const Arc *arcs_;
   size_t narcs_;
-  size_t i_;
+  size_t i_ = 0;
 };
 
 // Specialization for VectorFst; see generic version in mutable-fst.h for sample
@@ -739,7 +745,7 @@ class MutableArcIterator<VectorFst<Arc, State>>
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
 
-  MutableArcIterator(VectorFst<Arc, State> *fst, StateId s) : i_(0) {
+  MutableArcIterator(VectorFst<Arc, State> *fst, StateId s) {
     fst->MutateCheck();
     state_ = fst->GetMutableImpl()->GetState(s);
     properties_ = &fst->GetImpl()->properties_;
@@ -803,7 +809,7 @@ class MutableArcIterator<VectorFst<Arc, State>>
  private:
   State *state_;
   std::atomic<uint64_t> *properties_;
-  size_t i_;
+  size_t i_ = 0;
 };
 
 // Provides information needed for the generic mutable arc iterator.
